summaryrefslogtreecommitdiff
path: root/src
diff options
context:
space:
mode:
authorvrouvrea <vrouvrea@636b058d-ea47-450e-bf9e-a15bfbe3eedb>2016-06-30 16:02:15 +0000
committervrouvrea <vrouvrea@636b058d-ea47-450e-bf9e-a15bfbe3eedb>2016-06-30 16:02:15 +0000
commit8a84688f538eabfacfbbfdbf6cc8e159b1c3b412 (patch)
treee53090f1c6240168cfae190a870375892c8a8be8 /src
parenta931b662e64cca8d5ab0224c99742f3392b85f64 (diff)
Doc with sphinx
git-svn-id: svn+ssh://scm.gforge.inria.fr/svnroot/gudhi/branches/ST_cythonize@1369 636b058d-ea47-450e-bf9e-a15bfbe3eedb Former-commit-id: ad4fe8083b2659af5f34c71fa02decf63403bce4
Diffstat (limited to 'src')
-rw-r--r--src/cython/CMakeLists.txt22
-rw-r--r--src/cython/doc/Makefile177
-rw-r--r--src/cython/doc/make.bat242
-rwxr-xr-xsrc/cython/doc/source/conf.py269
-rw-r--r--src/cython/doc/source/index.rst64
-rw-r--r--src/cython/src/cython/alpha_complex.pyx37
-rw-r--r--src/cython/src/cython/cubical_complex.pyx25
-rw-r--r--src/cython/src/cython/mini_simplex_tree.pyx35
-rw-r--r--src/cython/src/cython/rips_complex.pyx35
-rw-r--r--src/cython/src/cython/simplex_tree.pyx35
-rw-r--r--src/cython/src/cython/witness_complex.pyx35
11 files changed, 893 insertions, 83 deletions
diff --git a/src/cython/CMakeLists.txt b/src/cython/CMakeLists.txt
index 27f6b99d..3989d5a1 100644
--- a/src/cython/CMakeLists.txt
+++ b/src/cython/CMakeLists.txt
@@ -74,6 +74,7 @@ if(PYTHON_PATH AND CYTHON_PATH)
add_custom_target(cythonize_gudhi ALL DEPENDS "${CMAKE_CURRENT_BINARY_DIR}/gudhi.so")
+ # Unitary tests are available through py.test
find_program( PYTEST_PATH py.test )
if(PYTEST_PATH)
add_test(
@@ -83,4 +84,25 @@ if(PYTHON_PATH AND CYTHON_PATH)
set_tests_properties(gudhi_cython_py_test PROPERTIES ENVIRONMENT "PYTHONPATH=${CMAKE_CURRENT_BINARY_DIR}")
endif(PYTEST_PATH)
+ # Documentation generation is available through sphinx
+ find_program( SPHINX_PATH sphinx-build )
+ if(SPHINX_PATH)
+ file(COPY doc DESTINATION ${CMAKE_CURRENT_BINARY_DIR})
+ # Developper version
+ file(GLOB GUDHI_DEV_DOC_IMAGES "${CMAKE_SOURCE_DIR}/src/*/doc/*.png")
+ file(COPY ${GUDHI_DEV_DOC_IMAGES} DESTINATION "${CMAKE_CURRENT_BINARY_DIR}/doc/source/img")
+ # User version
+ file(GLOB GUDHI_USER_DOC_IMAGES "${CMAKE_SOURCE_DIR}/doc/*/*.png")
+ file(COPY ${GUDHI_USER_DOC_IMAGES} DESTINATION "${CMAKE_CURRENT_BINARY_DIR}/doc/source/img")
+ if (UNIX)
+ add_custom_target(html
+ WORKING_DIRECTORY ${CMAKE_CURRENT_BINARY_DIR}/doc
+ COMMAND make html)
+ else (UNIX)
+ add_custom_target(html
+ WORKING_DIRECTORY ${CMAKE_CURRENT_BINARY_DIR}/doc
+ COMMAND make.bat html)
+ endif (UNIX)
+ endif(SPHINX_PATH)
+
endif(PYTHON_PATH AND CYTHON_PATH)
diff --git a/src/cython/doc/Makefile b/src/cython/doc/Makefile
new file mode 100644
index 00000000..e500e250
--- /dev/null
+++ b/src/cython/doc/Makefile
@@ -0,0 +1,177 @@
+# Makefile for Sphinx documentation
+#
+
+# You can set these variables from the command line.
+SPHINXOPTS =
+SPHINXBUILD = sphinx-build
+PAPER =
+BUILDDIR = build
+
+# User-friendly check for sphinx-build
+ifeq ($(shell which $(SPHINXBUILD) >/dev/null 2>&1; echo $$?), 1)
+$(error The '$(SPHINXBUILD)' command was not found. Make sure you have Sphinx installed, then set the SPHINXBUILD environment variable to point to the full path of the '$(SPHINXBUILD)' executable. Alternatively you can add the directory with the executable to your PATH. If you don't have Sphinx installed, grab it from http://sphinx-doc.org/)
+endif
+
+# Internal variables.
+PAPEROPT_a4 = -D latex_paper_size=a4
+PAPEROPT_letter = -D latex_paper_size=letter
+ALLSPHINXOPTS = -d $(BUILDDIR)/doctrees $(PAPEROPT_$(PAPER)) $(SPHINXOPTS) source
+# the i18n builder cannot share the environment and doctrees with the others
+I18NSPHINXOPTS = $(PAPEROPT_$(PAPER)) $(SPHINXOPTS) source
+
+.PHONY: help clean html dirhtml singlehtml pickle json htmlhelp qthelp devhelp epub latex latexpdf text man changes linkcheck doctest gettext
+
+help:
+ @echo "Please use \`make <target>' where <target> is one of"
+ @echo " html to make standalone HTML files"
+ @echo " dirhtml to make HTML files named index.html in directories"
+ @echo " singlehtml to make a single large HTML file"
+ @echo " pickle to make pickle files"
+ @echo " json to make JSON files"
+ @echo " htmlhelp to make HTML files and a HTML help project"
+ @echo " qthelp to make HTML files and a qthelp project"
+ @echo " devhelp to make HTML files and a Devhelp project"
+ @echo " epub to make an epub"
+ @echo " latex to make LaTeX files, you can set PAPER=a4 or PAPER=letter"
+ @echo " latexpdf to make LaTeX files and run them through pdflatex"
+ @echo " latexpdfja to make LaTeX files and run them through platex/dvipdfmx"
+ @echo " text to make text files"
+ @echo " man to make manual pages"
+ @echo " texinfo to make Texinfo files"
+ @echo " info to make Texinfo files and run them through makeinfo"
+ @echo " gettext to make PO message catalogs"
+ @echo " changes to make an overview of all changed/added/deprecated items"
+ @echo " xml to make Docutils-native XML files"
+ @echo " pseudoxml to make pseudoxml-XML files for display purposes"
+ @echo " linkcheck to check all external links for integrity"
+ @echo " doctest to run all doctests embedded in the documentation (if enabled)"
+
+clean:
+ rm -rf $(BUILDDIR)/*
+
+html:
+ $(SPHINXBUILD) -b html $(ALLSPHINXOPTS) $(BUILDDIR)/html
+ @echo
+ @echo "Build finished. The HTML pages are in $(BUILDDIR)/html."
+
+dirhtml:
+ $(SPHINXBUILD) -b dirhtml $(ALLSPHINXOPTS) $(BUILDDIR)/dirhtml
+ @echo
+ @echo "Build finished. The HTML pages are in $(BUILDDIR)/dirhtml."
+
+singlehtml:
+ $(SPHINXBUILD) -b singlehtml $(ALLSPHINXOPTS) $(BUILDDIR)/singlehtml
+ @echo
+ @echo "Build finished. The HTML page is in $(BUILDDIR)/singlehtml."
+
+pickle:
+ $(SPHINXBUILD) -b pickle $(ALLSPHINXOPTS) $(BUILDDIR)/pickle
+ @echo
+ @echo "Build finished; now you can process the pickle files."
+
+json:
+ $(SPHINXBUILD) -b json $(ALLSPHINXOPTS) $(BUILDDIR)/json
+ @echo
+ @echo "Build finished; now you can process the JSON files."
+
+htmlhelp:
+ $(SPHINXBUILD) -b htmlhelp $(ALLSPHINXOPTS) $(BUILDDIR)/htmlhelp
+ @echo
+ @echo "Build finished; now you can run HTML Help Workshop with the" \
+ ".hhp project file in $(BUILDDIR)/htmlhelp."
+
+qthelp:
+ $(SPHINXBUILD) -b qthelp $(ALLSPHINXOPTS) $(BUILDDIR)/qthelp
+ @echo
+ @echo "Build finished; now you can run "qcollectiongenerator" with the" \
+ ".qhcp project file in $(BUILDDIR)/qthelp, like this:"
+ @echo "# qcollectiongenerator $(BUILDDIR)/qthelp/GUDHI.qhcp"
+ @echo "To view the help file:"
+ @echo "# assistant -collectionFile $(BUILDDIR)/qthelp/GUDHI.qhc"
+
+devhelp:
+ $(SPHINXBUILD) -b devhelp $(ALLSPHINXOPTS) $(BUILDDIR)/devhelp
+ @echo
+ @echo "Build finished."
+ @echo "To view the help file:"
+ @echo "# mkdir -p $$HOME/.local/share/devhelp/GUDHI"
+ @echo "# ln -s $(BUILDDIR)/devhelp $$HOME/.local/share/devhelp/GUDHI"
+ @echo "# devhelp"
+
+epub:
+ $(SPHINXBUILD) -b epub $(ALLSPHINXOPTS) $(BUILDDIR)/epub
+ @echo
+ @echo "Build finished. The epub file is in $(BUILDDIR)/epub."
+
+latex:
+ $(SPHINXBUILD) -b latex $(ALLSPHINXOPTS) $(BUILDDIR)/latex
+ @echo
+ @echo "Build finished; the LaTeX files are in $(BUILDDIR)/latex."
+ @echo "Run \`make' in that directory to run these through (pdf)latex" \
+ "(use \`make latexpdf' here to do that automatically)."
+
+latexpdf:
+ $(SPHINXBUILD) -b latex $(ALLSPHINXOPTS) $(BUILDDIR)/latex
+ @echo "Running LaTeX files through pdflatex..."
+ $(MAKE) -C $(BUILDDIR)/latex all-pdf
+ @echo "pdflatex finished; the PDF files are in $(BUILDDIR)/latex."
+
+latexpdfja:
+ $(SPHINXBUILD) -b latex $(ALLSPHINXOPTS) $(BUILDDIR)/latex
+ @echo "Running LaTeX files through platex and dvipdfmx..."
+ $(MAKE) -C $(BUILDDIR)/latex all-pdf-ja
+ @echo "pdflatex finished; the PDF files are in $(BUILDDIR)/latex."
+
+text:
+ $(SPHINXBUILD) -b text $(ALLSPHINXOPTS) $(BUILDDIR)/text
+ @echo
+ @echo "Build finished. The text files are in $(BUILDDIR)/text."
+
+man:
+ $(SPHINXBUILD) -b man $(ALLSPHINXOPTS) $(BUILDDIR)/man
+ @echo
+ @echo "Build finished. The manual pages are in $(BUILDDIR)/man."
+
+texinfo:
+ $(SPHINXBUILD) -b texinfo $(ALLSPHINXOPTS) $(BUILDDIR)/texinfo
+ @echo
+ @echo "Build finished. The Texinfo files are in $(BUILDDIR)/texinfo."
+ @echo "Run \`make' in that directory to run these through makeinfo" \
+ "(use \`make info' here to do that automatically)."
+
+info:
+ $(SPHINXBUILD) -b texinfo $(ALLSPHINXOPTS) $(BUILDDIR)/texinfo
+ @echo "Running Texinfo files through makeinfo..."
+ make -C $(BUILDDIR)/texinfo info
+ @echo "makeinfo finished; the Info files are in $(BUILDDIR)/texinfo."
+
+gettext:
+ $(SPHINXBUILD) -b gettext $(I18NSPHINXOPTS) $(BUILDDIR)/locale
+ @echo
+ @echo "Build finished. The message catalogs are in $(BUILDDIR)/locale."
+
+changes:
+ $(SPHINXBUILD) -b changes $(ALLSPHINXOPTS) $(BUILDDIR)/changes
+ @echo
+ @echo "The overview file is in $(BUILDDIR)/changes."
+
+linkcheck:
+ $(SPHINXBUILD) -b linkcheck $(ALLSPHINXOPTS) $(BUILDDIR)/linkcheck
+ @echo
+ @echo "Link check complete; look for any errors in the above output " \
+ "or in $(BUILDDIR)/linkcheck/output.txt."
+
+doctest:
+ $(SPHINXBUILD) -b doctest $(ALLSPHINXOPTS) $(BUILDDIR)/doctest
+ @echo "Testing of doctests in the sources finished, look at the " \
+ "results in $(BUILDDIR)/doctest/output.txt."
+
+xml:
+ $(SPHINXBUILD) -b xml $(ALLSPHINXOPTS) $(BUILDDIR)/xml
+ @echo
+ @echo "Build finished. The XML files are in $(BUILDDIR)/xml."
+
+pseudoxml:
+ $(SPHINXBUILD) -b pseudoxml $(ALLSPHINXOPTS) $(BUILDDIR)/pseudoxml
+ @echo
+ @echo "Build finished. The pseudo-XML files are in $(BUILDDIR)/pseudoxml."
diff --git a/src/cython/doc/make.bat b/src/cython/doc/make.bat
new file mode 100644
index 00000000..cc6418d0
--- /dev/null
+++ b/src/cython/doc/make.bat
@@ -0,0 +1,242 @@
+@ECHO OFF
+
+REM Command file for Sphinx documentation
+
+if "%SPHINXBUILD%" == "" (
+ set SPHINXBUILD=sphinx-build
+)
+set BUILDDIR=build
+set ALLSPHINXOPTS=-d %BUILDDIR%/doctrees %SPHINXOPTS% source
+set I18NSPHINXOPTS=%SPHINXOPTS% source
+if NOT "%PAPER%" == "" (
+ set ALLSPHINXOPTS=-D latex_paper_size=%PAPER% %ALLSPHINXOPTS%
+ set I18NSPHINXOPTS=-D latex_paper_size=%PAPER% %I18NSPHINXOPTS%
+)
+
+if "%1" == "" goto help
+
+if "%1" == "help" (
+ :help
+ echo.Please use `make ^<target^>` where ^<target^> is one of
+ echo. html to make standalone HTML files
+ echo. dirhtml to make HTML files named index.html in directories
+ echo. singlehtml to make a single large HTML file
+ echo. pickle to make pickle files
+ echo. json to make JSON files
+ echo. htmlhelp to make HTML files and a HTML help project
+ echo. qthelp to make HTML files and a qthelp project
+ echo. devhelp to make HTML files and a Devhelp project
+ echo. epub to make an epub
+ echo. latex to make LaTeX files, you can set PAPER=a4 or PAPER=letter
+ echo. text to make text files
+ echo. man to make manual pages
+ echo. texinfo to make Texinfo files
+ echo. gettext to make PO message catalogs
+ echo. changes to make an overview over all changed/added/deprecated items
+ echo. xml to make Docutils-native XML files
+ echo. pseudoxml to make pseudoxml-XML files for display purposes
+ echo. linkcheck to check all external links for integrity
+ echo. doctest to run all doctests embedded in the documentation if enabled
+ goto end
+)
+
+if "%1" == "clean" (
+ for /d %%i in (%BUILDDIR%\*) do rmdir /q /s %%i
+ del /q /s %BUILDDIR%\*
+ goto end
+)
+
+
+%SPHINXBUILD% 2> nul
+if errorlevel 9009 (
+ echo.
+ echo.The 'sphinx-build' command was not found. Make sure you have Sphinx
+ echo.installed, then set the SPHINXBUILD environment variable to point
+ echo.to the full path of the 'sphinx-build' executable. Alternatively you
+ echo.may add the Sphinx directory to PATH.
+ echo.
+ echo.If you don't have Sphinx installed, grab it from
+ echo.http://sphinx-doc.org/
+ exit /b 1
+)
+
+if "%1" == "html" (
+ %SPHINXBUILD% -b html %ALLSPHINXOPTS% %BUILDDIR%/html
+ if errorlevel 1 exit /b 1
+ echo.
+ echo.Build finished. The HTML pages are in %BUILDDIR%/html.
+ goto end
+)
+
+if "%1" == "dirhtml" (
+ %SPHINXBUILD% -b dirhtml %ALLSPHINXOPTS% %BUILDDIR%/dirhtml
+ if errorlevel 1 exit /b 1
+ echo.
+ echo.Build finished. The HTML pages are in %BUILDDIR%/dirhtml.
+ goto end
+)
+
+if "%1" == "singlehtml" (
+ %SPHINXBUILD% -b singlehtml %ALLSPHINXOPTS% %BUILDDIR%/singlehtml
+ if errorlevel 1 exit /b 1
+ echo.
+ echo.Build finished. The HTML pages are in %BUILDDIR%/singlehtml.
+ goto end
+)
+
+if "%1" == "pickle" (
+ %SPHINXBUILD% -b pickle %ALLSPHINXOPTS% %BUILDDIR%/pickle
+ if errorlevel 1 exit /b 1
+ echo.
+ echo.Build finished; now you can process the pickle files.
+ goto end
+)
+
+if "%1" == "json" (
+ %SPHINXBUILD% -b json %ALLSPHINXOPTS% %BUILDDIR%/json
+ if errorlevel 1 exit /b 1
+ echo.
+ echo.Build finished; now you can process the JSON files.
+ goto end
+)
+
+if "%1" == "htmlhelp" (
+ %SPHINXBUILD% -b htmlhelp %ALLSPHINXOPTS% %BUILDDIR%/htmlhelp
+ if errorlevel 1 exit /b 1
+ echo.
+ echo.Build finished; now you can run HTML Help Workshop with the ^
+.hhp project file in %BUILDDIR%/htmlhelp.
+ goto end
+)
+
+if "%1" == "qthelp" (
+ %SPHINXBUILD% -b qthelp %ALLSPHINXOPTS% %BUILDDIR%/qthelp
+ if errorlevel 1 exit /b 1
+ echo.
+ echo.Build finished; now you can run "qcollectiongenerator" with the ^
+.qhcp project file in %BUILDDIR%/qthelp, like this:
+ echo.^> qcollectiongenerator %BUILDDIR%\qthelp\GUDHI.qhcp
+ echo.To view the help file:
+ echo.^> assistant -collectionFile %BUILDDIR%\qthelp\GUDHI.ghc
+ goto end
+)
+
+if "%1" == "devhelp" (
+ %SPHINXBUILD% -b devhelp %ALLSPHINXOPTS% %BUILDDIR%/devhelp
+ if errorlevel 1 exit /b 1
+ echo.
+ echo.Build finished.
+ goto end
+)
+
+if "%1" == "epub" (
+ %SPHINXBUILD% -b epub %ALLSPHINXOPTS% %BUILDDIR%/epub
+ if errorlevel 1 exit /b 1
+ echo.
+ echo.Build finished. The epub file is in %BUILDDIR%/epub.
+ goto end
+)
+
+if "%1" == "latex" (
+ %SPHINXBUILD% -b latex %ALLSPHINXOPTS% %BUILDDIR%/latex
+ if errorlevel 1 exit /b 1
+ echo.
+ echo.Build finished; the LaTeX files are in %BUILDDIR%/latex.
+ goto end
+)
+
+if "%1" == "latexpdf" (
+ %SPHINXBUILD% -b latex %ALLSPHINXOPTS% %BUILDDIR%/latex
+ cd %BUILDDIR%/latex
+ make all-pdf
+ cd %BUILDDIR%/..
+ echo.
+ echo.Build finished; the PDF files are in %BUILDDIR%/latex.
+ goto end
+)
+
+if "%1" == "latexpdfja" (
+ %SPHINXBUILD% -b latex %ALLSPHINXOPTS% %BUILDDIR%/latex
+ cd %BUILDDIR%/latex
+ make all-pdf-ja
+ cd %BUILDDIR%/..
+ echo.
+ echo.Build finished; the PDF files are in %BUILDDIR%/latex.
+ goto end
+)
+
+if "%1" == "text" (
+ %SPHINXBUILD% -b text %ALLSPHINXOPTS% %BUILDDIR%/text
+ if errorlevel 1 exit /b 1
+ echo.
+ echo.Build finished. The text files are in %BUILDDIR%/text.
+ goto end
+)
+
+if "%1" == "man" (
+ %SPHINXBUILD% -b man %ALLSPHINXOPTS% %BUILDDIR%/man
+ if errorlevel 1 exit /b 1
+ echo.
+ echo.Build finished. The manual pages are in %BUILDDIR%/man.
+ goto end
+)
+
+if "%1" == "texinfo" (
+ %SPHINXBUILD% -b texinfo %ALLSPHINXOPTS% %BUILDDIR%/texinfo
+ if errorlevel 1 exit /b 1
+ echo.
+ echo.Build finished. The Texinfo files are in %BUILDDIR%/texinfo.
+ goto end
+)
+
+if "%1" == "gettext" (
+ %SPHINXBUILD% -b gettext %I18NSPHINXOPTS% %BUILDDIR%/locale
+ if errorlevel 1 exit /b 1
+ echo.
+ echo.Build finished. The message catalogs are in %BUILDDIR%/locale.
+ goto end
+)
+
+if "%1" == "changes" (
+ %SPHINXBUILD% -b changes %ALLSPHINXOPTS% %BUILDDIR%/changes
+ if errorlevel 1 exit /b 1
+ echo.
+ echo.The overview file is in %BUILDDIR%/changes.
+ goto end
+)
+
+if "%1" == "linkcheck" (
+ %SPHINXBUILD% -b linkcheck %ALLSPHINXOPTS% %BUILDDIR%/linkcheck
+ if errorlevel 1 exit /b 1
+ echo.
+ echo.Link check complete; look for any errors in the above output ^
+or in %BUILDDIR%/linkcheck/output.txt.
+ goto end
+)
+
+if "%1" == "doctest" (
+ %SPHINXBUILD% -b doctest %ALLSPHINXOPTS% %BUILDDIR%/doctest
+ if errorlevel 1 exit /b 1
+ echo.
+ echo.Testing of doctests in the sources finished, look at the ^
+results in %BUILDDIR%/doctest/output.txt.
+ goto end
+)
+
+if "%1" == "xml" (
+ %SPHINXBUILD% -b xml %ALLSPHINXOPTS% %BUILDDIR%/xml
+ if errorlevel 1 exit /b 1
+ echo.
+ echo.Build finished. The XML files are in %BUILDDIR%/xml.
+ goto end
+)
+
+if "%1" == "pseudoxml" (
+ %SPHINXBUILD% -b pseudoxml %ALLSPHINXOPTS% %BUILDDIR%/pseudoxml
+ if errorlevel 1 exit /b 1
+ echo.
+ echo.Build finished. The pseudo-XML files are in %BUILDDIR%/pseudoxml.
+ goto end
+)
+
+:end
diff --git a/src/cython/doc/source/conf.py b/src/cython/doc/source/conf.py
new file mode 100755
index 00000000..094020f7
--- /dev/null
+++ b/src/cython/doc/source/conf.py
@@ -0,0 +1,269 @@
+# -*- coding: utf-8 -*-
+#
+# GUDHI documentation build configuration file, created by
+# sphinx-quickstart on Thu Jun 30 09:55:51 2016.
+#
+# This file is execfile()d with the current directory set to its
+# containing dir.
+#
+# Note that not all possible configuration values are present in this
+# autogenerated file.
+#
+# All configuration values have a default; values that are commented out
+# serve to show the default.
+
+import sys
+import os
+
+# If extensions (or modules to document with autodoc) are in another directory,
+# add these directories to sys.path here. If the directory is relative to the
+# documentation root, use os.path.abspath to make it absolute, like shown here.
+#sys.path.insert(0, os.path.abspath('.'))
+
+# Path to Gudhi.so from source path
+sys.path.insert(0, os.path.abspath('../..'))
+
+# -- General configuration ------------------------------------------------
+
+# If your documentation needs a minimal Sphinx version, state it here.
+#needs_sphinx = '1.0'
+
+# Add any Sphinx extension module names here, as strings. They can be
+# extensions coming with Sphinx (named 'sphinx.ext.*') or your custom
+# ones.
+extensions = [
+ 'sphinx.ext.autodoc',
+ 'sphinx.ext.doctest',
+ 'sphinx.ext.todo',
+ 'sphinx.ext.coverage',
+ 'sphinx.ext.mathjax',
+ 'sphinx.ext.ifconfig',
+ 'sphinx.ext.viewcode',
+]
+
+# Add any paths that contain templates here, relative to this directory.
+templates_path = ['_templates']
+
+# The suffix of source filenames.
+source_suffix = '.rst'
+
+# The encoding of source files.
+#source_encoding = 'utf-8-sig'
+
+# The master toctree document.
+master_doc = 'index'
+
+# General information about the project.
+project = u'GUDHI'
+copyright = u'2016, Vincent Rouvreau'
+
+# The version info for the project you're documenting, acts as replacement for
+# |version| and |release|, also used in various other places throughout the
+# built documents.
+#
+# The short X.Y version.
+version = '1.3.1'
+# The full version, including alpha/beta/rc tags.
+release = '1.3.1'
+
+# The language for content autogenerated by Sphinx. Refer to documentation
+# for a list of supported languages.
+#language = None
+
+# There are two options for replacing |today|: either, you set today to some
+# non-false value, then it is used:
+#today = ''
+# Else, today_fmt is used as the format for a strftime call.
+#today_fmt = '%B %d, %Y'
+
+# List of patterns, relative to source directory, that match files and
+# directories to ignore when looking for source files.
+exclude_patterns = []
+
+# The reST default role (used for this markup: `text`) to use for all
+# documents.
+#default_role = None
+
+# If true, '()' will be appended to :func: etc. cross-reference text.
+#add_function_parentheses = True
+
+# If true, the current module name will be prepended to all description
+# unit titles (such as .. function::).
+#add_module_names = True
+
+# If true, sectionauthor and moduleauthor directives will be shown in the
+# output. They are ignored by default.
+#show_authors = False
+
+# The name of the Pygments (syntax highlighting) style to use.
+pygments_style = 'sphinx'
+
+# A list of ignored prefixes for module index sorting.
+#modindex_common_prefix = []
+
+# If true, keep warnings as "system message" paragraphs in the built documents.
+#keep_warnings = False
+
+
+# -- Options for HTML output ----------------------------------------------
+
+# The theme to use for HTML and HTML Help pages. See the documentation for
+# a list of builtin themes.
+html_theme = 'default'
+
+# Theme options are theme-specific and customize the look and feel of a theme
+# further. For a list of options available for each theme, see the
+# documentation.
+#html_theme_options = {}
+
+# Add any paths that contain custom themes here, relative to this directory.
+#html_theme_path = []
+
+# The name for this set of Sphinx documents. If None, it defaults to
+# "<project> v<release> documentation".
+#html_title = None
+
+# A shorter title for the navigation bar. Default is the same as html_title.
+#html_short_title = None
+
+# The name of an image file (relative to this directory) to place at the top
+# of the sidebar.
+#html_logo = None
+
+# The name of an image file (within the static path) to use as favicon of the
+# docs. This file should be a Windows icon file (.ico) being 16x16 or 32x32
+# pixels large.
+#html_favicon = None
+
+# Add any paths that contain custom static files (such as style sheets) here,
+# relative to this directory. They are copied after the builtin static files,
+# so a file named "default.css" will overwrite the builtin "default.css".
+html_static_path = ['_static']
+
+# Add any extra paths that contain custom files (such as robots.txt or
+# .htaccess) here, relative to this directory. These files are copied
+# directly to the root of the documentation.
+#html_extra_path = []
+
+# If not '', a 'Last updated on:' timestamp is inserted at every page bottom,
+# using the given strftime format.
+#html_last_updated_fmt = '%b %d, %Y'
+
+# If true, SmartyPants will be used to convert quotes and dashes to
+# typographically correct entities.
+#html_use_smartypants = True
+
+# Custom sidebar templates, maps document names to template names.
+#html_sidebars = {}
+
+# Additional templates that should be rendered to pages, maps page names to
+# template names.
+#html_additional_pages = {}
+
+# If false, no module index is generated.
+#html_domain_indices = True
+
+# If false, no index is generated.
+#html_use_index = True
+
+# If true, the index is split into individual pages for each letter.
+#html_split_index = False
+
+# If true, links to the reST sources are added to the pages.
+#html_show_sourcelink = True
+
+# If true, "Created using Sphinx" is shown in the HTML footer. Default is True.
+#html_show_sphinx = True
+
+# If true, "(C) Copyright ..." is shown in the HTML footer. Default is True.
+#html_show_copyright = True
+
+# If true, an OpenSearch description file will be output, and all pages will
+# contain a <link> tag referring to it. The value of this option must be the
+# base URL from which the finished HTML is served.
+#html_use_opensearch = ''
+
+# This is the file name suffix for HTML files (e.g. ".xhtml").
+#html_file_suffix = None
+
+# Output file base name for HTML help builder.
+htmlhelp_basename = 'GUDHIdoc'
+
+
+# -- Options for LaTeX output ---------------------------------------------
+
+latex_elements = {
+# The paper size ('letterpaper' or 'a4paper').
+#'papersize': 'letterpaper',
+
+# The font size ('10pt', '11pt' or '12pt').
+#'pointsize': '10pt',
+
+# Additional stuff for the LaTeX preamble.
+#'preamble': '',
+}
+
+# Grouping the document tree into LaTeX files. List of tuples
+# (source start file, target name, title,
+# author, documentclass [howto, manual, or own class]).
+latex_documents = [
+ ('index', 'GUDHI.tex', u'GUDHI Documentation',
+ u'Vincent Rouvreau', 'manual'),
+]
+
+# The name of an image file (relative to this directory) to place at the top of
+# the title page.
+#latex_logo = None
+
+# For "manual" documents, if this is true, then toplevel headings are parts,
+# not chapters.
+#latex_use_parts = False
+
+# If true, show page references after internal links.
+#latex_show_pagerefs = False
+
+# If true, show URL addresses after external links.
+#latex_show_urls = False
+
+# Documents to append as an appendix to all manuals.
+#latex_appendices = []
+
+# If false, no module index is generated.
+#latex_domain_indices = True
+
+
+# -- Options for manual page output ---------------------------------------
+
+# One entry per manual page. List of tuples
+# (source start file, name, description, authors, manual section).
+man_pages = [
+ ('index', 'gudhi', u'GUDHI Documentation',
+ [u'Vincent Rouvreau'], 1)
+]
+
+# If true, show URL addresses after external links.
+#man_show_urls = False
+
+
+# -- Options for Texinfo output -------------------------------------------
+
+# Grouping the document tree into Texinfo files. List of tuples
+# (source start file, target name, title, author,
+# dir menu entry, description, category)
+texinfo_documents = [
+ ('index', 'GUDHI', u'GUDHI Documentation',
+ u'Vincent Rouvreau', 'GUDHI', 'One line description of project.',
+ 'Miscellaneous'),
+]
+
+# Documents to append as an appendix to all manuals.
+#texinfo_appendices = []
+
+# If false, no module index is generated.
+#texinfo_domain_indices = True
+
+# How to display URL addresses: 'footnote', 'no', or 'inline'.
+#texinfo_show_urls = 'footnote'
+
+# If true, do not generate a @detailmenu in the "Top" node's menu.
+#texinfo_no_detailmenu = False
diff --git a/src/cython/doc/source/index.rst b/src/cython/doc/source/index.rst
new file mode 100644
index 00000000..7dfea239
--- /dev/null
+++ b/src/cython/doc/source/index.rst
@@ -0,0 +1,64 @@
+.. GUDHI documentation master file, created by
+ sphinx-quickstart on Thu Jun 30 09:55:51 2016.
+ You can adapt this file completely to your liking, but it should at least
+ contain the root `toctree` directive.
+
+.. toctree::
+ :maxdepth: 2
+
+GUDHI's documentation
+#####################
+
+.. image:: img/Gudhi_banner.png
+ :align: center
+
+Introduction
+************
+
+The Gudhi library (Geometry Understanding in Higher Dimensions) is a generic
+open source C++ library for Computational Topology and Topological Data
+Analysis (TDA). The GUDHI library intends to help the development of new
+algorithmic solutions in TDA and their transfer to applications. It provides
+robust, efficient, flexible and easy to use implementations of
+state-of-the-art algorithms and data structures.
+
+The current release of the GUDHI library includes:
+
+* Data structures to represent, construct and manipulate simplicial complexes.
+* Algorithms to compute persistent homology and multi-field persistent homology.
+* Simplication of simplicial complexes by edge contraction.
+
+All data-structures are generic and several of their aspects can be
+parameterized via template classes. We refer to [14] for a detailed
+description of the design of the library.
+
+Data structures
+***************
+
+Alpha complex
+=============
+
+.. image:: img/alpha_complex_representation.png
+ :align: center
+
+Alpha_complex is a simplicial complex constructed from the finite cells of a
+Delaunay Triangulation.
+
+The filtration value of each simplex is computed as the square of the
+circumradius of the simplex if the circumsphere is empty (the simplex is then
+said to be Gabriel), and as the minimum of the filtration values of the
+codimension 1 cofaces that make it not Gabriel otherwise. All simplices that
+have a filtration value strictly greater than a given alpha squared value are
+not inserted into the complex.
+
+This package requires having CGAL version 4.7 or higher (4.8.1 is advised for
+better perfomances).
+
+* :ref:`alphacomplex`
+
+
+.. automodule:: gudhi
+ :members:
+ :undoc-members:
+ :show-inheritance:
+
diff --git a/src/cython/src/cython/cubical_complex.pyx b/src/cython/src/cython/cubical_complex.pyx
index 402d264c..52137520 100644
--- a/src/cython/src/cython/cubical_complex.pyx
+++ b/src/cython/src/cython/cubical_complex.pyx
@@ -98,14 +98,15 @@ cdef class CubicalComplex:
"""This function returns the persistence of the simplicial complex.
:param homology_coeff_field: The homology coefficient field. Must be a
- prime number
+ prime number
:type homology_coeff_field: int.
:param min_persistence: The minimum persistence value to take into
- account (strictly greater than min_persistence). Default value is 0.0.
- Sets min_persistence to -1.0 to see all values.
+ account (strictly greater than min_persistence). Default value is
+ 0.0.
+ Sets min_persistence to -1.0 to see all values.
:type min_persistence: float.
- :returns: list of tuples(dimension, tuple(birth, death)) -- the star tree of a
- simplex.
+ :returns: list of pairs(dimension, pair(birth, death)) -- the
+ persistence of the simplicial complex.
"""
if self.pcohptr != NULL:
del self.pcohptr
@@ -121,8 +122,8 @@ cdef class CubicalComplex:
:returns: list of int -- The Betti numbers ([B0, B1, ..., Bn]).
- :warning: betti_numbers function requires persistence function to be
- launched first.
+ :note: betti_numbers function requires persistence function to be
+ launched first.
"""
cdef vector[int] bn_result
if self.pcohptr != NULL:
@@ -134,17 +135,17 @@ cdef class CubicalComplex:
simplicial complex.
:param from_value: The persistence birth limit to be added in the
- numbers (persistent birth <= from_value).
+ numbers (persistent birth <= from_value).
:type from_value: float.
:param to_value: The persistence death limit to be added in the
- numbers (persistent death > to_value).
+ numbers (persistent death > to_value).
:type to_value: float.
:returns: list of int -- The persistent Betti numbers ([B0, B1, ...,
- Bn]).
+ Bn]).
- :warning: betti_numbers function requires persistence function to be
- launched first.
+ :note: persistent_betti_numbers function requires persistence
+ function to be launched first.
"""
cdef vector[int] pbn_result
if self.pcohptr != NULL:
diff --git a/src/cython/src/cython/mini_simplex_tree.pyx b/src/cython/src/cython/mini_simplex_tree.pyx
index 813316af..c045c727 100644
--- a/src/cython/src/cython/mini_simplex_tree.pyx
+++ b/src/cython/src/cython/mini_simplex_tree.pyx
@@ -179,7 +179,7 @@ cdef class MiniSimplexTree:
value (default value is '0.0').
:param simplex: The N-simplex to insert, represented by a list of
- vertex.
+ vertex.
:type simplex: list of int.
:param filtration: The filtration value of the simplex.
:type filtration: float.
@@ -196,7 +196,7 @@ cdef class MiniSimplexTree:
values.
:returns: list of tuples(simplex, filtration) -- the tree sorted by
- increasing filtration values.
+ increasing filtration values.
"""
cdef vector[pair[vector[int], double]] coface_tree \
= self.thisptr.get_filtered_tree()
@@ -215,7 +215,7 @@ cdef class MiniSimplexTree:
:param dimension: The skeleton dimension value.
:type dimension: int.
:returns: list of tuples(simplex, filtration) -- the skeleton tree
- of a maximum dimension.
+ of a maximum dimension.
"""
cdef vector[pair[vector[int], double]] coface_tree \
= self.thisptr.get_skeleton_tree(<int>dimension)
@@ -233,7 +233,7 @@ cdef class MiniSimplexTree:
:param simplex: The N-simplex, represented by a list of vertex.
:type simplex: list of int.
:returns: list of tuples(simplex, filtration) -- the star tree of a
- simplex.
+ simplex.
"""
cdef vector[int] complex
for i in simplex:
@@ -255,10 +255,10 @@ cdef class MiniSimplexTree:
:param simplex: The N-simplex, represented by a list of vertex.
:type simplex: list of int.
:param codimension: The codimension. If codimension = 0, all cofaces
- are returned (equivalent of get_star_tree function)
+ are returned (equivalent of get_star_tree function)
:type codimension: int.
:returns: list of tuples(simplex, filtration) -- the coface tree of a
- simplex.
+ simplex.
"""
cdef vector[int] complex
for i in simplex:
@@ -286,14 +286,15 @@ cdef class MiniSimplexTree:
"""This function returns the persistence of the simplicial complex.
:param homology_coeff_field: The homology coefficient field. Must be a
- prime number
+ prime number
:type homology_coeff_field: int.
:param min_persistence: The minimum persistence value to take into
- account (strictly greater than min_persistence). Default value is 0.0.
- Sets min_persistence to -1.0 to see all values.
+ account (strictly greater than min_persistence). Default value is
+ 0.0.
+ Sets min_persistence to -1.0 to see all values.
:type min_persistence: float.
- :returns: list of tuples(dimension, tuple(birth, death)) -- the star tree of a
- simplex.
+ :returns: list of pairs(dimension, pair(birth, death)) -- the
+ persistence of the simplicial complex.
"""
if self.pcohptr != NULL:
del self.pcohptr
@@ -307,6 +308,9 @@ cdef class MiniSimplexTree:
"""This function returns the Betti numbers of the simplicial complex.
:returns: list of int -- The Betti numbers ([B0, B1, ..., Bn]).
+
+ :note: betti_numbers function requires persistence function to be
+ launched first.
"""
cdef vector[int] bn_result
if self.pcohptr != NULL:
@@ -321,14 +325,17 @@ cdef class MiniSimplexTree:
simplicial complex.
:param from_value: The persistence birth limit to be added in the
- numbers (persistent birth <= from_value).
+ numbers (persistent birth <= from_value).
:type from_value: float.
:param to_value: The persistence death limit to be added in the
- numbers (persistent death > to_value).
+ numbers (persistent death > to_value).
:type to_value: float.
:returns: list of int -- The persistent Betti numbers ([B0, B1, ...,
- Bn]).
+ Bn]).
+
+ :note: persistent_betti_numbers function requires persistence
+ function to be launched first.
"""
cdef vector[int] pbn_result
if self.pcohptr != NULL:
diff --git a/src/cython/src/cython/rips_complex.pyx b/src/cython/src/cython/rips_complex.pyx
index 4d713304..7e07f36b 100644
--- a/src/cython/src/cython/rips_complex.pyx
+++ b/src/cython/src/cython/rips_complex.pyx
@@ -195,7 +195,7 @@ cdef class RipsComplex:
value (default value is '0.0').
:param simplex: The N-simplex to insert, represented by a list of
- vertex.
+ vertex.
:type simplex: list of int.
:param filtration: The filtration value of the simplex.
:type filtration: float.
@@ -212,7 +212,7 @@ cdef class RipsComplex:
values.
:returns: list of tuples(simplex, filtration) -- the tree sorted by
- increasing filtration values.
+ increasing filtration values.
"""
cdef vector[pair[vector[int], double]] coface_tree \
= self.thisptr.get_filtered_tree()
@@ -231,7 +231,7 @@ cdef class RipsComplex:
:param dimension: The skeleton dimension value.
:type dimension: int.
:returns: list of tuples(simplex, filtration) -- the skeleton tree
- of a maximum dimension.
+ of a maximum dimension.
"""
cdef vector[pair[vector[int], double]] coface_tree \
= self.thisptr.get_skeleton_tree(<int>dimension)
@@ -249,7 +249,7 @@ cdef class RipsComplex:
:param simplex: The N-simplex, represented by a list of vertex.
:type simplex: list of int.
:returns: list of tuples(simplex, filtration) -- the star tree of a
- simplex.
+ simplex.
"""
cdef vector[int] complex
for i in simplex:
@@ -271,10 +271,10 @@ cdef class RipsComplex:
:param simplex: The N-simplex, represented by a list of vertex.
:type simplex: list of int.
:param codimension: The codimension. If codimension = 0, all cofaces
- are returned (equivalent of get_star_tree function)
+ are returned (equivalent of get_star_tree function)
:type codimension: int.
:returns: list of tuples(simplex, filtration) -- the coface tree of a
- simplex.
+ simplex.
"""
cdef vector[int] complex
for i in simplex:
@@ -302,14 +302,15 @@ cdef class RipsComplex:
"""This function returns the persistence of the simplicial complex.
:param homology_coeff_field: The homology coefficient field. Must be a
- prime number
+ prime number
:type homology_coeff_field: int.
:param min_persistence: The minimum persistence value to take into
- account (strictly greater than min_persistence). Default value is 0.0.
- Sets min_persistence to -1.0 to see all values.
+ account (strictly greater than min_persistence). Default value is
+ 0.0.
+ Sets min_persistence to -1.0 to see all values.
:type min_persistence: float.
- :returns: list of tuples(dimension, tuple(birth, death)) -- the star tree of a
- simplex.
+ :note: list of pairs(dimension, pair(birth, death)) -- the
+ persistence of the simplicial complex.
"""
if self.pcohptr != NULL:
del self.pcohptr
@@ -323,6 +324,9 @@ cdef class RipsComplex:
"""This function returns the Betti numbers of the simplicial complex.
:returns: list of int -- The Betti numbers ([B0, B1, ..., Bn]).
+
+ :note: betti_numbers function requires persistence function to be
+ launched first.
"""
cdef vector[int] bn_result
if self.pcohptr != NULL:
@@ -337,14 +341,17 @@ cdef class RipsComplex:
simplicial complex.
:param from_value: The persistence birth limit to be added in the
- numbers (persistent birth <= from_value).
+ numbers (persistent birth <= from_value).
:type from_value: float.
:param to_value: The persistence death limit to be added in the
- numbers (persistent death > to_value).
+ numbers (persistent death > to_value).
:type to_value: float.
:returns: list of int -- The persistent Betti numbers ([B0, B1, ...,
- Bn]).
+ Bn]).
+
+ :note: persistent_betti_numbers function requires persistence
+ function to be launched first.
"""
cdef vector[int] pbn_result
if self.pcohptr != NULL:
diff --git a/src/cython/src/cython/simplex_tree.pyx b/src/cython/src/cython/simplex_tree.pyx
index c0c783b4..772ea73d 100644
--- a/src/cython/src/cython/simplex_tree.pyx
+++ b/src/cython/src/cython/simplex_tree.pyx
@@ -179,7 +179,7 @@ cdef class SimplexTree:
value (default value is '0.0').
:param simplex: The N-simplex to insert, represented by a list of
- vertex.
+ vertex.
:type simplex: list of int.
:param filtration: The filtration value of the simplex.
:type filtration: float.
@@ -196,7 +196,7 @@ cdef class SimplexTree:
values.
:returns: list of tuples(simplex, filtration) -- the tree sorted by
- increasing filtration values.
+ increasing filtration values.
"""
cdef vector[pair[vector[int], double]] coface_tree \
= self.thisptr.get_filtered_tree()
@@ -215,7 +215,7 @@ cdef class SimplexTree:
:param dimension: The skeleton dimension value.
:type dimension: int.
:returns: list of tuples(simplex, filtration) -- the skeleton tree
- of a maximum dimension.
+ of a maximum dimension.
"""
cdef vector[pair[vector[int], double]] coface_tree \
= self.thisptr.get_skeleton_tree(<int>dimension)
@@ -233,7 +233,7 @@ cdef class SimplexTree:
:param simplex: The N-simplex, represented by a list of vertex.
:type simplex: list of int.
:returns: list of tuples(simplex, filtration) -- the star tree of a
- simplex.
+ simplex.
"""
cdef vector[int] complex
for i in simplex:
@@ -255,10 +255,10 @@ cdef class SimplexTree:
:param simplex: The N-simplex, represented by a list of vertex.
:type simplex: list of int.
:param codimension: The codimension. If codimension = 0, all cofaces
- are returned (equivalent of get_star_tree function)
+ are returned (equivalent of get_star_tree function)
:type codimension: int.
:returns: list of tuples(simplex, filtration) -- the coface tree of a
- simplex.
+ simplex.
"""
cdef vector[int] complex
for i in simplex:
@@ -286,14 +286,15 @@ cdef class SimplexTree:
"""This function returns the persistence of the simplicial complex.
:param homology_coeff_field: The homology coefficient field. Must be a
- prime number
+ prime number
:type homology_coeff_field: int.
:param min_persistence: The minimum persistence value to take into
- account (strictly greater than min_persistence). Default value is 0.0.
- Sets min_persistence to -1.0 to see all values.
+ account (strictly greater than min_persistence). Default value is
+ 0.0.
+ Sets min_persistence to -1.0 to see all values.
:type min_persistence: float.
- :returns: list of tuples(dimension, tuple(birth, death)) -- the star tree of a
- simplex.
+ :note: list of pairs(dimension, pair(birth, death)) -- the
+ persistence of the simplicial complex.
"""
if self.pcohptr != NULL:
del self.pcohptr
@@ -307,6 +308,9 @@ cdef class SimplexTree:
"""This function returns the Betti numbers of the simplicial complex.
:returns: list of int -- The Betti numbers ([B0, B1, ..., Bn]).
+
+ :note: betti_numbers function requires persistence function to be
+ launched first.
"""
cdef vector[int] bn_result
if self.pcohptr != NULL:
@@ -321,14 +325,17 @@ cdef class SimplexTree:
simplicial complex.
:param from_value: The persistence birth limit to be added in the
- numbers (persistent birth <= from_value).
+ numbers (persistent birth <= from_value).
:type from_value: float.
:param to_value: The persistence death limit to be added in the
- numbers (persistent death > to_value).
+ numbers (persistent death > to_value).
:type to_value: float.
:returns: list of int -- The persistent Betti numbers ([B0, B1, ...,
- Bn]).
+ Bn]).
+
+ :note: persistent_betti_numbers function requires persistence
+ function to be launched first.
"""
cdef vector[int] pbn_result
if self.pcohptr != NULL:
diff --git a/src/cython/src/cython/witness_complex.pyx b/src/cython/src/cython/witness_complex.pyx
index 0f08bdcb..bdbdc393 100644
--- a/src/cython/src/cython/witness_complex.pyx
+++ b/src/cython/src/cython/witness_complex.pyx
@@ -168,7 +168,7 @@ cdef class WitnessComplex:
value (default value is '0.0').
:param simplex: The N-simplex to insert, represented by a list of
- vertex.
+ vertex.
:type simplex: list of int.
:param filtration: The filtration value of the simplex.
:type filtration: float.
@@ -185,7 +185,7 @@ cdef class WitnessComplex:
values.
:returns: list of tuples(simplex, filtration) -- the tree sorted by
- increasing filtration values.
+ increasing filtration values.
"""
cdef vector[pair[vector[int], double]] coface_tree \
= self.thisptr.get_filtered_tree()
@@ -204,7 +204,7 @@ cdef class WitnessComplex:
:param dimension: The skeleton dimension value.
:type dimension: int.
:returns: list of tuples(simplex, filtration) -- the skeleton tree
- of a maximum dimension.
+ of a maximum dimension.
"""
cdef vector[pair[vector[int], double]] coface_tree \
= self.thisptr.get_skeleton_tree(<int>dimension)
@@ -222,7 +222,7 @@ cdef class WitnessComplex:
:param simplex: The N-simplex, represented by a list of vertex.
:type simplex: list of int.
:returns: list of tuples(simplex, filtration) -- the star tree of a
- simplex.
+ simplex.
"""
cdef vector[int] complex
for i in simplex:
@@ -244,10 +244,10 @@ cdef class WitnessComplex:
:param simplex: The N-simplex, represented by a list of vertex.
:type simplex: list of int.
:param codimension: The codimension. If codimension = 0, all cofaces
- are returned (equivalent of get_star_tree function)
+ are returned (equivalent of get_star_tree function)
:type codimension: int.
:returns: list of tuples(simplex, filtration) -- the coface tree of a
- simplex.
+ simplex.
"""
cdef vector[int] complex
for i in simplex:
@@ -275,14 +275,15 @@ cdef class WitnessComplex:
"""This function returns the persistence of the simplicial complex.
:param homology_coeff_field: The homology coefficient field. Must be a
- prime number
+ prime number
:type homology_coeff_field: int.
:param min_persistence: The minimum persistence value to take into
- account (strictly greater than min_persistence). Default value is 0.0.
- Sets min_persistence to -1.0 to see all values.
+ account (strictly greater than min_persistence). Default value is
+ 0.0.
+ Sets min_persistence to -1.0 to see all values.
:type min_persistence: float.
- :returns: list of tuples(dimension, tuple(birth, death)) -- the star tree of a
- simplex.
+ :note: list of pairs(dimension, pair(birth, death)) -- the
+ persistence of the simplicial complex.
"""
return self.thisptr.get_persistence(homology_coeff_field, min_persistence)
@@ -290,6 +291,9 @@ cdef class WitnessComplex:
"""This function returns the Betti numbers of the simplicial complex.
:returns: list of int -- The Betti numbers ([B0, B1, ..., Bn]).
+
+ :note: betti_numbers function requires persistence function to be
+ launched first.
"""
return self.thisptr.get_betti_numbers()
@@ -298,13 +302,16 @@ cdef class WitnessComplex:
simplicial complex.
:param from_value: The persistence birth limit to be added in the
- numbers (persistent birth <= from_value).
+ numbers (persistent birth <= from_value).
:type from_value: float.
:param to_value: The persistence death limit to be added in the
- numbers (persistent death > to_value).
+ numbers (persistent death > to_value).
:type to_value: float.
:returns: list of int -- The persistent Betti numbers ([B0, B1, ...,
- Bn]).
+ Bn]).
+
+ :note: persistent_betti_numbers function requires persistence
+ function to be launched first.
"""
return self.thisptr.get_persistent_betti_numbers(from_value, to_value)
diff --git a/src/cython/src/cython/alpha_complex.pyx b/src/cython/src/cython/alpha_complex.pyx
index 39e930f4..f36de661 100644
--- a/src/cython/src/cython/alpha_complex.pyx
+++ b/src/cython/src/cython/alpha_complex.pyx
@@ -193,7 +193,7 @@ cdef class AlphaComplex:
value (default value is '0.0').
:param simplex: The N-simplex to insert, represented by a list of
- vertex.
+ vertex.
:type simplex: list of int.
:param filtration: The filtration value of the simplex.
:type filtration: float.
@@ -210,7 +210,7 @@ cdef class AlphaComplex:
values.
:returns: list of tuples(simplex, filtration) -- the tree sorted by
- increasing filtration values.
+ increasing filtration values.
"""
cdef vector[pair[vector[int], double]] coface_tree \
= self.thisptr.get_filtered_tree()
@@ -229,7 +229,7 @@ cdef class AlphaComplex:
:param dimension: The skeleton dimension value.
:type dimension: int.
:returns: list of tuples(simplex, filtration) -- the skeleton tree
- of a maximum dimension.
+ of a maximum dimension.
"""
cdef vector[pair[vector[int], double]] coface_tree \
= self.thisptr.get_skeleton_tree(<int>dimension)
@@ -247,7 +247,7 @@ cdef class AlphaComplex:
:param simplex: The N-simplex, represented by a list of vertex.
:type simplex: list of int.
:returns: list of tuples(simplex, filtration) -- the star tree of a
- simplex.
+ simplex.
"""
cdef vector[int] complex
for i in simplex:
@@ -269,10 +269,10 @@ cdef class AlphaComplex:
:param simplex: The N-simplex, represented by a list of vertex.
:type simplex: list of int.
:param codimension: The codimension. If codimension = 0, all cofaces
- are returned (equivalent of get_star_tree function)
+ are returned (equivalent of get_star_tree function)
:type codimension: int.
- :returns: list of tuples(simplex, filtration) -- the coface tree of a
- simplex.
+ :returns: list of tuples(simplex, filtration) -- the coface tree of a
+ simplex.
"""
cdef vector[int] complex
for i in simplex:
@@ -310,14 +310,15 @@ cdef class AlphaComplex:
"""This function returns the persistence of the simplicial complex.
:param homology_coeff_field: The homology coefficient field. Must be a
- prime number
+ prime number
:type homology_coeff_field: int.
:param min_persistence: The minimum persistence value to take into
- account (strictly greater than min_persistence). Default value is 0.0.
- Sets min_persistence to -1.0 to see all values.
+ account (strictly greater than min_persistence). Default value is
+ 0.0.
+ Sets min_persistence to -1.0 to see all values.
:type min_persistence: float.
- :returns: list of tuples(dimension, tuple(birth, death)) -- the star tree of a
- simplex.
+ :returns: list of tuples(dimension, tuple(birth, death)) -- the
+ persistence of the simplicial complex.
"""
if self.pcohptr != NULL:
del self.pcohptr
@@ -333,6 +334,9 @@ cdef class AlphaComplex:
"""This function returns the Betti numbers of the simplicial complex.
:returns: list of int -- The Betti numbers ([B0, B1, ..., Bn]).
+
+ :note: betti_numbers function requires persistence function to be
+ launched first.
"""
cdef vector[int] bn_result
if self.pcohptr != NULL:
@@ -347,14 +351,17 @@ cdef class AlphaComplex:
simplicial complex.
:param from_value: The persistence birth limit to be added in the
- numbers (persistent birth <= from_value).
+ numbers (persistent birth <= from_value).
:type from_value: float.
:param to_value: The persistence death limit to be added in the
- numbers (persistent death > to_value).
+ numbers (persistent death > to_value).
:type to_value: float.
:returns: list of int -- The persistent Betti numbers ([B0, B1, ...,
- Bn]).
+ Bn]).
+
+ :note: persistent_betti_numbers function requires persistence
+ function to be launched first.
"""
cdef vector[int] pbn_result
if self.pcohptr != NULL: